from  kolibri_report.report import Report
from kolibri.model_trainer import ModelTrainer,ModelConfig
from kolibri.model_loader import ModelLoader
import os
import pandas as pd

data = pd.read_csv('/Users/aneruthmohanasundaram/Documents/Office/kolibri_doc/wine.csv')

confg = {}
confg['do-lower-case'] = True
confg['language'] = 'en'
confg['filter-stopwords'] = True
confg["model"] = 'RandomForestClassifier'
confg["n_estimators"] = 100
confg['output-folder'] = '/Users/aneruthmohanasundaram/Documents/Office/kolibri_doc/demos'
confg['pipeline']= ['SklearnEstimator']
confg['target']= 'type'

X = data.drop('type',axis=1)
y = data.type

trainer=ModelTrainer(ModelConfig(confg))

trainer.fit(X, y)

model_directory = trainer.persist(confg['output-folder'], fixed_model_name="current")
model_interpreter = ModelLoader.load(os.path.join(confg['output-folder'], 'current'))

app_report = Report(data)
app_report.run()
os.system(f"streamlit run {__file__}")


from setuptools import setup,find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="kolibri-report",
    version="0.0.7",
    author="Aneruth",
    author_email="ane1998@gmail.com",
    description="A report package for kolibri-ml",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Aneruth/kolibri-report",
    project_urls={
        "Bug Tracker": "https://github.com/Aneruth/kolibri-report/issues",
    },
    install_requires=["kolibri-ml","seaborn"],
    package_data={
        # If any package contains *.txt or *.rst files, include them:
        '': ['*.txt', '*.rst', '*.json', '*.npy', '*.db'],
    },
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3.7",
        "Operating System :: OS Independent",
        'Development Status :: 1 - Planning',
        'Intended Audience :: Developers',
    ],
    python_requires='>=3.7',
)